diff --git a/templates/display/results/value_display.twig b/templates/display/results/value_display.twig
new file mode 100644
index 0000000000..35640b91ca
--- /dev/null
+++ b/templates/display/results/value_display.twig
@@ -0,0 +1,3 @@
+
+ {{ value|raw }}
+ |
diff --git a/test/classes/Display/ResultsTest.php b/test/classes/Display/ResultsTest.php
index 28b98abe03..87cde0cf56 100644
--- a/test/classes/Display/ResultsTest.php
+++ b/test/classes/Display/ResultsTest.php
@@ -1491,11 +1491,13 @@ class ResultsTest extends PmaTestCase
array(),
0,
'binary',
- '' . PHP_EOL
+ . ' [BLOB - 4 B] | '
+ . 'class="disableAjax">[BLOB - 4 B]' . PHP_EOL
+ . '' . PHP_EOL
),
array(
'noblob',
@@ -1512,8 +1514,9 @@ class ResultsTest extends PmaTestCase
array(),
0,
'binary',
- ''
- . '1001 | '
+ '' . PHP_EOL
+ . ' 1001' . PHP_EOL
+ . ' | ' . PHP_EOL
),
array(
'noblob',
diff --git a/libraries/classes/Display/Results.php b/libraries/classes/Display/Results.php
index 854505ea06..88be9626b9 100644
--- a/libraries/classes/Display/Results.php
+++ b/libraries/classes/Display/Results.php
@@ -2339,9 +2339,9 @@ class Results
/**
* Prepares the display for a value
*
* @param string $class class of table cell
* @param bool $condition_field whether to add CSS class condition
* @param string $value value to display
*
* @return string the td
*
@@ -2350,12 +2350,14 @@ class Results
* @see _getDataCellForGeometryColumns(),
* _getDataCellForNonNumericColumns()
*/
- private function _buildValueDisplay($class, $condition_field, $value)
+ private function _buildValueDisplay($class, $conditionField, $value)
{
- return '
' . $value . ' | ';
- } // end of the '_buildValueDisplay()' function
-
+ return Template::get('display/results/value_display')->render([
+ 'class' => $class,
+ 'condition_field' => $conditionField,
+ 'value' => $value,
+ ]);
+ }
/**
* Prepares the display for a null value
@@ -2339,9 +2339,9 @@ class Results
* Prepares the display for a value
*
- * @param string $class class of table cell
- * @param bool $condition_field whether to add CSS class condition
- * @param string $value value to display
+ * @param string $class class of table cell
+ * @param bool $conditionField whether to add CSS class condition
+ * @param string $value value to display
*
* @return string the td